#[non_exhaustive]pub struct StringAttributeValues {
pub values: Vec<String>,
/* private fields */
}Expand description
The attribute values of data type string or JSON.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.values: Vec<String>Required. The attribute values in case attribute data type is string or JSON.
Implementations
Sourceimpl StringAttributeValues
impl StringAttributeValues
pub fn new() -> Self
Sourcepub fn set_values<T, V>(self, v: T) -> Self
pub fn set_values<T, V>(self, v: T) -> Self