#[non_exhaustive]pub struct MultiSelectValues {
pub values: Vec<ConfigValueOption>,
/* private fields */
}Expand description
The config variable value of data type multi select.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.values: Vec<ConfigValueOption>Optional. The config variable value of data type multi select.
Implementations
Sourceimpl MultiSelectValues
impl MultiSelectValues
pub fn new() -> Self
Sourcepub fn set_values<T, V>(self, v: T) -> Self
pub fn set_values<T, V>(self, v: T) -> Self