#[non_exhaustive]pub struct MultiStringValues {
pub values: Vec<String>,
/* private fields */
}Expand description
The config variable value of data type multi string.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.values: Vec<String>Optional. The config variable value of data type multi string.
Implementations
Sourceimpl MultiStringValues
impl MultiStringValues
pub fn new() -> Self
Sourcepub fn set_values<T, V>(self, v: T) -> Self
pub fn set_values<T, V>(self, v: T) -> Self