#[non_exhaustive]pub enum CollectionType {
Unspecified,
Upsert,
Delete,
UnknownValue(UnknownValue),
}Expand description
The type of the collect request.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default value. This value is used if the collection type is omitted.
Upsert
The collection type is upsert. This should be used when an API is created or updated at the source.
Delete
The collection type is delete. This should be used when an API is deleted at the source.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using CollectionType::value or CollectionType::name.
Implementations