#[non_exhaustive]pub enum State {
Unspecified,
Enabled,
Disabled,
UnknownValue(UnknownValue),
}Expand description
Possible states a plugin can have. Note that this enum may receive new values in the future. Consumers are advised to always code against the enum values expecting new states can be added later on.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The default value. This value is used if the state is omitted.
Enabled
The plugin is enabled.
Disabled
The plugin is disabled.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations