#[non_exhaustive]pub struct HostingService {
pub service_uri: String,
/* private fields */
}Expand description
The information related to the service implemented by the plugin developer, used to invoke the plugin’s functionality.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_uri: StringOptional. The URI of the service implemented by the plugin developer, used to invoke the plugin’s functionality. This information is only required for user defined plugins.
Implementations
Sourceimpl HostingService
impl HostingService