#[non_exhaustive]pub enum State {
Unspecified,
Creating,
Active,
ApplyingConfig,
Error,
Failed,
Deleting,
UnknownValue(UnknownValue),
}Expand description
State represents the state of the plugin instance.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default unspecified state.
Creating
The plugin instance is being created.
Active
The plugin instance is active and ready for executions. This is the only state where executions can run on the plugin instance.
ApplyingConfig
The updated config that contains additional_config and auth_config is being applied.
Error
The ERROR state can come while applying config. Users can retrigger [ApplyPluginInstanceConfig][google.cloud.apihub.v1.ApiHubPlugin.ApplyPluginInstanceConfig] to restore the plugin instance back to active state. Note, In case the ERROR state happens while applying config (auth_config, additional_config), the plugin instance will reflect the config which was trying to be applied while error happened. In order to overwrite, trigger ApplyConfig with a new config.
Failed
The plugin instance is in a failed state. This indicates that an unrecoverable error occurred during a previous operation (Create, Delete).
Deleting
The plugin instance is being deleted. Delete is only possible if there is no other operation running on the plugin instance and plugin instance action.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations