#[non_exhaustive]pub enum State {
Unspecified,
Enabled,
Disabled,
Enabling,
Disabling,
Error,
UnknownValue(UnknownValue),
}Expand description
State represents the state of the plugin instance action.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Default unspecified state.
Enabled
The action is enabled in the plugin instance i.e., executions can be triggered for this action.
Disabled
The action is disabled in the plugin instance i.e., no executions can be triggered for this action. This state indicates that the user explicitly disabled the instance, and no further action is needed unless the user wants to re-enable it.
Enabling
The action in the plugin instance is being enabled.
Disabling
The action in the plugin instance is being disabled.
Error
The ERROR state can come while enabling/disabling plugin instance action. Users can retrigger enable, disable via EnablePluginInstanceAction and DisablePluginInstanceAction to restore the action back to enabled/disabled state. Note enable/disable on actions can only be triggered if plugin instance is in Active state.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations