#[non_exhaustive]pub struct CreateCurationRequest {
pub parent: String,
pub curation_id: String,
pub curation: Option<Curation>,
/* private fields */
}Expand description
The [CreateCuration][ApiHub.CreateCuration] method’s request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource for the curation resource.
Format: projects/{project}/locations/{location}
curation_id: StringOptional. The ID to use for the curation resource, which will become the final component of the curations’s resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified ID is already used by another curation resource in the API hub.
- If not provided, a system generated ID will be used.
This value should be 4-500 characters, and valid characters are /[a-z][A-Z][0-9]-_/.
curation: Option<Curation>Required. The curation resource to create.
Implementations
Sourceimpl CreateCurationRequest
impl CreateCurationRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_curation_id<T: Into<String>>(self, v: T) -> Self
pub fn set_curation_id<T: Into<String>>(self, v: T) -> Self
Sets the value of curation_id.
Example
ⓘ
let x = CreateCurationRequest::new().set_curation_id("example");Sourcepub fn set_curation<T>(self, v: T) -> Self
pub fn set_curation<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_curation<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_curation<T>(self, v: Option<T>) -> Self