CreateHostProjectRegistrationRequest

Struct CreateHostProjectRegistrationRequest 

#[non_exhaustive]
pub struct CreateHostProjectRegistrationRequest { pub parent: String, pub host_project_registration_id: String, pub host_project_registration: Option<HostProjectRegistration>, /* private fields */ }
The CreateHostProjectRegistration method’s request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent resource for the host project. Format: projects/{project}/locations/{location}

host_project_registration_id: String

Required. The ID to use for the Host Project Registration, which will become the final component of the host project registration’s resource name. The ID must be the same as the Google cloud project specified in the host_project_registration.gcp_project field.

host_project_registration: Option<HostProjectRegistration>

Required. The host project registration to register.

Implementations

Source

impl CreateHostProjectRegistrationRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateHostProjectRegistrationRequest::new().set_parent("example");
pub fn set_host_project_registration_id<T: Into<String>>(self, v: T) -> Self

Sets the value of host_project_registration_id.

Example
let x = CreateHostProjectRegistrationRequest::new().set_host_project_registration_id("example");
pub fn set_host_project_registration<T>(self, v: T) -> Self

Sets the value of host_project_registration.

Example
use google_cloud_apihub_v1::model::HostProjectRegistration;
let x = CreateHostProjectRegistrationRequest::new().set_host_project_registration(HostProjectRegistration::default()/* use setters */);
pub fn set_or_clear_host_project_registration<T>(self, v: Option<T>) -> Self

Sets or clears the value of host_project_registration.

Example
use google_cloud_apihub_v1::model::HostProjectRegistration;
let x = CreateHostProjectRegistrationRequest::new().set_or_clear_host_project_registration(Some(HostProjectRegistration::default()/* use setters */));
let x = CreateHostProjectRegistrationRequest::new().set_or_clear_host_project_registration(None::<HostProjectRegistration>);