#[non_exhaustive]pub struct CreatePluginInstanceRequest {
pub parent: String,
pub plugin_instance_id: String,
pub plugin_instance: Option<PluginInstance>,
/* private fields */
}Expand description
The CreatePluginInstance method’s request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent of the plugin instance resource.
Format: projects/{project}/locations/{location}/plugins/{plugin}
plugin_instance_id: StringOptional. The ID to use for the plugin instance, which will become the final component of the plugin instance’s resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified id is already used by another plugin instance in the plugin resource.
- If not provided, a system generated id will be used.
This value should be 4-63 characters, and valid characters are /[a-z][A-Z][0-9]-_/.
plugin_instance: Option<PluginInstance>Required. The plugin instance to create.
Implementations
Sourceimpl CreatePluginInstanceRequest
impl CreatePluginInstanceRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_plugin_instance_id<T: Into<String>>(self, v: T) -> Self
pub fn set_plugin_instance_id<T: Into<String>>(self, v: T) -> Self
Sets the value of plugin_instance_id.
Example
ⓘ
let x = CreatePluginInstanceRequest::new().set_plugin_instance_id("example");Sourcepub fn set_plugin_instance<T>(self, v: T) -> Selfwhere
T: Into<PluginInstance>,
pub fn set_plugin_instance<T>(self, v: T) -> Selfwhere
T: Into<PluginInstance>,
Sets the value of plugin_instance.
Example
ⓘ
use google_cloud_apihub_v1::model::PluginInstance;
let x = CreatePluginInstanceRequest::new().set_plugin_instance(PluginInstance::default()/* use setters */);Sourcepub fn set_or_clear_plugin_instance<T>(self, v: Option<T>) -> Selfwhere
T: Into<PluginInstance>,
pub fn set_or_clear_plugin_instance<T>(self, v: Option<T>) -> Selfwhere
T: Into<PluginInstance>,
Sets or clears the value of plugin_instance.
Example
ⓘ
use google_cloud_apihub_v1::model::PluginInstance;
let x = CreatePluginInstanceRequest::new().set_or_clear_plugin_instance(Some(PluginInstance::default()/* use setters */));
let x = CreatePluginInstanceRequest::new().set_or_clear_plugin_instance(None::<PluginInstance>);Trait Implementations
Sourceimpl Clone for CreatePluginInstanceRequest
impl Clone for CreatePluginInstanceRequest
Sourcefn clone(&self) -> CreatePluginInstanceRequest
fn clone(&self) -> CreatePluginInstanceRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreatePluginInstanceRequest
impl Debug for CreatePluginInstanceRequest
Sourceimpl Default for CreatePluginInstanceRequest
impl Default for CreatePluginInstanceRequest
Sourcefn default() -> CreatePluginInstanceRequest
fn default() -> CreatePluginInstanceRequest
Returns the “default value” for a type. Read more
impl StructuralPartialEq for CreatePluginInstanceRequest