CreatePluginRequest

Struct CreatePluginRequest 

#[non_exhaustive]
pub struct CreatePluginRequest { pub parent: String, pub plugin_id: String, pub plugin: Option<Plugin>, /* private fields */ }
The CreatePlugin method’s request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent resource where this plugin will be created. Format: projects/{project}/locations/{location}.

plugin_id: String

Optional. The ID to use for the Plugin resource, which will become the final component of the Plugin’s resource name. This field is optional.

  • If provided, the same will be used. The service will throw an error if the specified id is already used by another Plugin resource in the API hub instance.
  • If not provided, a system generated id will be used.

This value should be 4-63 characters, overall resource name which will be of format projects/{project}/locations/{location}/plugins/{plugin}, its length is limited to 1000 characters and valid characters are /[a-z][A-Z][0-9]-_/.

plugin: Option<Plugin>

Required. The plugin to create.

Implementations

Source

impl CreatePluginRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreatePluginRequest::new().set_parent("example");
pub fn set_plugin_id<T: Into<String>>(self, v: T) -> Self

Sets the value of plugin_id.

Example
let x = CreatePluginRequest::new().set_plugin_id("example");
pub fn set_plugin<T>(self, v: T) -> Self
where T: Into<Plugin>,

Sets the value of plugin.

Example
use google_cloud_apihub_v1::model::Plugin;
let x = CreatePluginRequest::new().set_plugin(Plugin::default()/* use setters */);
pub fn set_or_clear_plugin<T>(self, v: Option<T>) -> Self
where T: Into<Plugin>,

Sets or clears the value of plugin.

Example
use google_cloud_apihub_v1::model::Plugin;
let x = CreatePluginRequest::new().set_or_clear_plugin(Some(Plugin::default()/* use setters */));
let x = CreatePluginRequest::new().set_or_clear_plugin(None::<Plugin>);