CreateRuntimeProjectAttachmentRequest

Struct CreateRuntimeProjectAttachmentRequest 

#[non_exhaustive]
pub struct CreateRuntimeProjectAttachmentRequest { pub parent: String, pub runtime_project_attachment_id: String, pub runtime_project_attachment: Option<RuntimeProjectAttachment>, /* private fields */ }
The CreateRuntimeProjectAttachment method’s request.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
parent: String

Required. The parent resource for the Runtime Project Attachment. Format: projects/{project}/locations/{location}

runtime_project_attachment_id: String

Required. The ID to use for the Runtime Project Attachment, which will become the final component of the Runtime Project Attachment’s name. The ID must be the same as the project ID of the Google cloud project specified in the runtime_project_attachment.runtime_project field.

runtime_project_attachment: Option<RuntimeProjectAttachment>

Required. The Runtime Project Attachment to create.

Implementations

Source

impl CreateRuntimeProjectAttachmentRequest

pub fn new() -> Self

pub fn set_parent<T: Into<String>>(self, v: T) -> Self

Sets the value of parent.

Example
let x = CreateRuntimeProjectAttachmentRequest::new().set_parent("example");
pub fn set_runtime_project_attachment_id<T: Into<String>>(self, v: T) -> Self

Sets the value of runtime_project_attachment_id.

Example
let x = CreateRuntimeProjectAttachmentRequest::new().set_runtime_project_attachment_id("example");
pub fn set_runtime_project_attachment<T>(self, v: T) -> Self

Sets the value of runtime_project_attachment.

Example
use google_cloud_apihub_v1::model::RuntimeProjectAttachment;
let x = CreateRuntimeProjectAttachmentRequest::new().set_runtime_project_attachment(RuntimeProjectAttachment::default()/* use setters */);
pub fn set_or_clear_runtime_project_attachment<T>(self, v: Option<T>) -> Self

Sets or clears the value of runtime_project_attachment.

Example
use google_cloud_apihub_v1::model::RuntimeProjectAttachment;
let x = CreateRuntimeProjectAttachmentRequest::new().set_or_clear_runtime_project_attachment(Some(RuntimeProjectAttachment::default()/* use setters */));
let x = CreateRuntimeProjectAttachmentRequest::new().set_or_clear_runtime_project_attachment(None::<RuntimeProjectAttachment>);