#[non_exhaustive]pub struct CreateSpecRequest {
pub parent: String,
pub spec_id: String,
pub spec: Option<Spec>,
/* private fields */
}Expand description
The CreateSpec method’s request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource for Spec.
Format:
projects/{project}/locations/{location}/apis/{api}/versions/{version}
spec_id: StringOptional. The ID to use for the spec, which will become the final component of the spec’s resource name. This field is optional.
- If provided, the same will be used. The service will throw an error if the specified id is already used by another spec in the API resource.
- If not provided, a system generated id will be used.
This value should be 4-500 characters, overall resource name which will be
of format
projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec},
its length is limited to 1000 characters and valid characters are
/[a-z][A-Z][0-9]-_/.
spec: Option<Spec>Required. The spec to create.
Implementations
Sourceimpl CreateSpecRequest
impl CreateSpecRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_spec_id<T: Into<String>>(self, v: T) -> Self
pub fn set_spec_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_spec<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_spec<T>(self, v: Option<T>) -> Self