#[non_exhaustive]pub struct DependencyEntityReference {
pub display_name: String,
pub identifier: Option<Identifier>,
/* private fields */
}Expand description
Reference to an entity participating in a dependency.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: StringOutput only. Display name of the entity.
identifier: Option<Identifier>Required. Unique identifier for the participating entity.
Implementations
Sourceimpl DependencyEntityReference
impl DependencyEntityReference
pub fn new() -> Self
Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = DependencyEntityReference::new().set_display_name("example");Sourcepub fn set_identifier<T: Into<Option<Identifier>>>(self, v: T) -> Self
pub fn set_identifier<T: Into<Option<Identifier>>>(self, v: T) -> Self
Sets the value of identifier.
Note that all the setters affecting identifier are mutually
exclusive.
Example
use google_cloud_apihub_v1::model::dependency_entity_reference::Identifier;
let x = DependencyEntityReference::new().set_identifier(Some(Identifier::OperationResourceName("example".to_string())));Sourcepub fn operation_resource_name(&self) -> Option<&String>
pub fn operation_resource_name(&self) -> Option<&String>
The value of identifier
if it holds a OperationResourceName, None if the field is not set or
holds a different branch.
Sourcepub fn set_operation_resource_name<T: Into<String>>(self, v: T) -> Self
pub fn set_operation_resource_name<T: Into<String>>(self, v: T) -> Self
Sets the value of identifier
to hold a OperationResourceName.
Note that all the setters affecting identifier are
mutually exclusive.
Example
let x = DependencyEntityReference::new().set_operation_resource_name("example");
assert!(x.operation_resource_name().is_some());
assert!(x.external_api_resource_name().is_none());Sourcepub fn external_api_resource_name(&self) -> Option<&String>
pub fn external_api_resource_name(&self) -> Option<&String>
The value of identifier
if it holds a ExternalApiResourceName, None if the field is not set or
holds a different branch.
Sourcepub fn set_external_api_resource_name<T: Into<String>>(self, v: T) -> Self
pub fn set_external_api_resource_name<T: Into<String>>(self, v: T) -> Self
Sets the value of identifier
to hold a ExternalApiResourceName.
Note that all the setters affecting identifier are
mutually exclusive.
Example
let x = DependencyEntityReference::new().set_external_api_resource_name("example");
assert!(x.external_api_resource_name().is_some());
assert!(x.operation_resource_name().is_none());Trait Implementations
Sourceimpl Clone for DependencyEntityReference
impl Clone for DependencyEntityReference
Sourcefn clone(&self) -> DependencyEntityReference
fn clone(&self) -> DependencyEntityReference
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more