GoogleServiceAccountConfig

Struct GoogleServiceAccountConfig 

#[non_exhaustive]
pub struct GoogleServiceAccountConfig { pub service_account: String, /* private fields */ }
Config for Google service account authentication.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
service_account: String

Required. The service account to be used for authenticating request.

The iam.serviceAccounts.getAccessToken permission should be granted on this service account to the impersonator service account.

Implementations

Source

impl GoogleServiceAccountConfig

pub fn new() -> Self

pub fn set_service_account<T: Into<String>>(self, v: T) -> Self

Sets the value of service_account.

Example
let x = GoogleServiceAccountConfig::new().set_service_account("example");