#[non_exhaustive]pub struct ListRuntimeProjectAttachmentsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
The ListRuntimeProjectAttachments method’s request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns this collection of runtime project
attachments. Format: projects/{project}/locations/{location}
page_size: i32Optional. The maximum number of runtime project attachments to return. The service may return fewer than this value. If unspecified, at most 50 runtime project attachments will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
page_token: StringOptional. A page token, received from a previous
ListRuntimeProjectAttachments call. Provide this to retrieve the
subsequent page.
When paginating, all other parameters (except page_size) provided to
ListRuntimeProjectAttachments must match the call that provided the page
token.
filter: StringOptional. An expression that filters the list of RuntimeProjectAttachments.
A filter expression consists of a field name, a comparison operator, and a value for filtering. The value must be a string. All standard operators as documented at https://google.aip.dev/160 are supported.
The following fields in the RuntimeProjectAttachment are eligible for
filtering:
name- The name of the RuntimeProjectAttachment.create_time- The time at which the RuntimeProjectAttachment was created. The value should be in the (RFC3339)[https://tools.ietf.org/html/rfc3339] format.runtime_project- The Google cloud project associated with the RuntimeProjectAttachment.
order_by: StringOptional. Hint for how to order the results.
Implementations
Sourceimpl ListRuntimeProjectAttachmentsRequest
impl ListRuntimeProjectAttachmentsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListRuntimeProjectAttachmentsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self