#[non_exhaustive]pub struct Path {
pub path: String,
pub description: String,
/* private fields */
}Expand description
The path details derived from the spec.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.path: StringOptional. Complete path relative to server endpoint. Note: Even though this field is optional, it is required for CreateApiOperation API and we will fail the request if not provided.
description: StringOptional. A short description for the path applicable to all operations.
Implementations