#[non_exhaustive]pub struct CreateRuntimeProjectAttachmentRequest {
pub parent: String,
pub runtime_project_attachment_id: String,
pub runtime_project_attachment: Option<RuntimeProjectAttachment>,
/* private fields */
}Expand description
The CreateRuntimeProjectAttachment method’s request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource for the Runtime Project Attachment.
Format: projects/{project}/locations/{location}
runtime_project_attachment_id: StringRequired. The ID to use for the Runtime Project Attachment, which will become the final component of the Runtime Project Attachment’s name. The ID must be the same as the project ID of the Google cloud project specified in the runtime_project_attachment.runtime_project field.
runtime_project_attachment: Option<RuntimeProjectAttachment>Required. The Runtime Project Attachment to create.
Implementations
Sourceimpl CreateRuntimeProjectAttachmentRequest
impl CreateRuntimeProjectAttachmentRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_runtime_project_attachment_id<T: Into<String>>(self, v: T) -> Self
pub fn set_runtime_project_attachment_id<T: Into<String>>(self, v: T) -> Self
Sets the value of runtime_project_attachment_id.
Example
ⓘ
let x = CreateRuntimeProjectAttachmentRequest::new().set_runtime_project_attachment_id("example");Sourcepub fn set_runtime_project_attachment<T>(self, v: T) -> Selfwhere
T: Into<RuntimeProjectAttachment>,
pub fn set_runtime_project_attachment<T>(self, v: T) -> Selfwhere
T: Into<RuntimeProjectAttachment>,
Sets the value of runtime_project_attachment.
Example
ⓘ
use google_cloud_apihub_v1::model::RuntimeProjectAttachment;
let x = CreateRuntimeProjectAttachmentRequest::new().set_runtime_project_attachment(RuntimeProjectAttachment::default()/* use setters */);Sourcepub fn set_or_clear_runtime_project_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuntimeProjectAttachment>,
pub fn set_or_clear_runtime_project_attachment<T>(self, v: Option<T>) -> Selfwhere
T: Into<RuntimeProjectAttachment>,
Sets or clears the value of runtime_project_attachment.
Example
ⓘ
use google_cloud_apihub_v1::model::RuntimeProjectAttachment;
let x = CreateRuntimeProjectAttachmentRequest::new().set_or_clear_runtime_project_attachment(Some(RuntimeProjectAttachment::default()/* use setters */));
let x = CreateRuntimeProjectAttachmentRequest::new().set_or_clear_runtime_project_attachment(None::<RuntimeProjectAttachment>);Trait Implementations
Sourceimpl Clone for CreateRuntimeProjectAttachmentRequest
impl Clone for CreateRuntimeProjectAttachmentRequest
Sourcefn clone(&self) -> CreateRuntimeProjectAttachmentRequest
fn clone(&self) -> CreateRuntimeProjectAttachmentRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateRuntimeProjectAttachmentRequest
impl Default for CreateRuntimeProjectAttachmentRequest
Sourcefn default() -> CreateRuntimeProjectAttachmentRequest
fn default() -> CreateRuntimeProjectAttachmentRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateRuntimeProjectAttachmentRequest
impl PartialEq for CreateRuntimeProjectAttachmentRequest
Sourcefn eq(&self, other: &CreateRuntimeProjectAttachmentRequest) -> bool
fn eq(&self, other: &CreateRuntimeProjectAttachmentRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateRuntimeProjectAttachmentRequest